#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.18
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:                   haskell-ci-0.18-G3OkG8mcTYZL4pk5CK6n0c-haskell-ci-internal
key:                  haskell-ci-0.18-G3OkG8mcTYZL4pk5CK6n0c-haskell-ci-internal
license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for
    [GitHub Actions](https://docs.github.com/en/actions) and
    [Travis-CI](https://travis-ci.org/)
    for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  3fd9184ce7e2b8a5e3e4b99cee46f944
exposed-modules:
    HaskellCI HaskellCI.Auxiliary HaskellCI.Bash
    HaskellCI.Bash.Template HaskellCI.Cabal HaskellCI.Cli
    HaskellCI.Compiler HaskellCI.Config HaskellCI.Config.Components
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Docspec HaskellCI.Config.Doctest
    HaskellCI.Config.Dump HaskellCI.Config.Empty HaskellCI.Config.Folds
    HaskellCI.Config.HLint HaskellCI.Config.Installed
    HaskellCI.Config.Jobs HaskellCI.Config.PackageScope
    HaskellCI.Config.Ubuntu HaskellCI.Config.Validity
    HaskellCI.Diagnostics HaskellCI.Error HaskellCI.Ghcup
    HaskellCI.GitConfig HaskellCI.GitHub HaskellCI.GitHub.Yaml
    HaskellCI.HeadHackage HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-ci-0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-ci-0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-ci-0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ci
hs-libraries:
    HShaskell-ci-0.18-G3OkG8mcTYZL4pk5CK6n0c-haskell-ci-internal

depends:
    Cabal-syntax-3.10.3.0 HsYAML-0.2.1.5-Jz8w0o1sgfkHmTJjLcFBwG
    ShellCheck-0.11.0-yW8EtYvrh2CHMjDpIA3tB
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g
    attoparsec-0.14.4-IK8bf7Jdhmx3QhZQbOSRoN base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    base16-bytestring-1.0.2.0-DtNKPfG3uwoHKAxlYu0flv binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-parsers-0.6.1.1-JryjocZpoqwHVW6tvdnEL9
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-JQ3h3OqBjPV3JHEv8ufozr deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    generic-lens-lite-0.1.1-6FrqAuYwkr79qeSIo4PrbF
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    indexed-traversable-instances-0.1.2.1-G4VjSv3TEPP9d4nVmSaXwJ
    ini-0.4.2-8qigi8jXN2G3rN3ClgAtoV
    lattices-2.2.1.1-I8Abo6P6mQ5I73ikbcRSgI mtl-2.3.1
    network-uri-2.6.4.2-CMtdZ463jfq9hso9AZHHZa
    optparse-applicative-0.18.1.0-1Cqb5McLkWg4t2rBtbfPtX
    parsec-3.1.16.1 pretty-1.1.3.6 process-1.6.19.0
    temporary-1.3-Klgi73SzFBU6HdICepglv2 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs
    zinza-0.2.1-G6Lvp0Y00t34q3YzVq0KH

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

